@@ -1,3 +1,4 @@
+import logging
 import os
 from pathlib import Path
 
@@ -14,3 +15,5 @@ __all__ = [
     'EsRequest',
     'UserAuth'
 ]
+
+logging.getLogger(__name__).addHandler(logging.NullHandler())
