@@ -18,7 +18,3 @@ class RefreshTokenExpiredError(Exception):
 
     def __str__(self):
         return f'{self.message}'
-
-
-class NotLoginError(Exception):
-    pass
