@@ -1,3 +1,4 @@
+import logging
 from pathlib import Path
 from typing import Optional
 
@@ -5,9 +6,10 @@ import requests
 from elasticsearch_dsl import Search
 from elasticsearch_dsl.response import Response
 
-from minetext import EsRequest, UserAuth
 from .config import Config
-from .exceptions import NotLoginError
+from .domain.es_request import EsRequest
+from .domain.user_auth import UserAuth
+from .exceptions import RefreshTokenExpiredError
 from .model.access_token import AccessToken
 from .model.device_token import DeviceToken
 
@@ -92,50 +94,58 @@ class Mine:
 
         return response
 
-    def login(self) -> None:
+    def login(self, save_credentials: bool = True, credentials_location: Path = None) -> None:
         """
         Calls the functions to authorize user.
 
-        Waits for the user to log in into the verification uri and afterwards creates an access token if the user
-        stated they granted access.
-        """
-        self._device_token = self._user_auth.create_device_token()
-        print(f'Please sign in at this website and grant access: {self._device_token.verification_uri_complete}')
-        input_str = input('Did you grant the access? [y/N]')
-        if input_str != 'y':
-            return
-        self._access_token = self._user_auth.create_access_token(device_code=self._device_token.device_code)
-        print('Login successful! You are now authorized.')
+        It first checks if the credentials is already available at ``credentials_location``. If yes, it will try to
+        authenticate using the refresh token found in that credentials. In case the credentials is not found in the
+        system, or the refresh token is already expired, the full login process is triggered.
 
-    def save_credentials(self, location: Path = None) -> None:
-        """
-        Serialize the access token to a file.
+        In the full login process, users need to follow the URL printed in the console to log in, grant access
+        to the app, and response to the console input.
 
         Parameters
         ----------
-        location : :py:class:`~pathlib.Path`, default=$HOME/.minetext/user.pickle
+        save_credentials : bool, default=True
+            Indicate if the credentials should be saved in the machine after login.
+        credentials_location: :py:class:`~pathlib.Path`, default=$HOME/.minetext/user.pickle
             Where the file should be stored. The path must also include the file name.
-
-        Raises
-        ------
-        NotLoginError
-            When the access token does not exist yet.
         """
-        if self._access_token:
-            self._user_auth.save_credentials(self._access_token, location)
-        else:
-            raise NotLoginError('The credentials is missing. Maybe you did not log in yet.')
+        logger = logging.getLogger(__name__)
 
-    def load_credentials(self, location: Path = None) -> None:
-        """
-        Load the :py:class:`~minetext.model.access_token.AccessToken` object from a file.
+        if not credentials_location:
+            credentials_location = self._user_auth.default_file_location
 
-        Parameters
-        ----------
-        location : :py:class:`~pathlib.Path`, default=$HOME/.minetext/user.pickle
-            Where the file is stored. The path must also include the file name.
-        """
-        self._access_token = self._user_auth.load_credentials(location)
+        need_login_again = False
+
+        try:
+            # Load credentials
+            logger.info(f'Loading credentials at {credentials_location}')
+            self._access_token = self._user_auth.load_credentials(credentials_location)
+
+            # Obtain new token
+            logger.info('Obtaining new access token...')
+            self._access_token = self._user_auth.refresh_token(self._access_token)
+        except FileNotFoundError:
+            need_login_again = True
+            logger.info(f'Token is not found at {credentials_location}')
+        except RefreshTokenExpiredError as e:
+            logger.info(e.message)
+            need_login_again = True
+
+        if need_login_again:
+            self._device_token = self._user_auth.create_device_token()
+            print(f'Please sign in at this website and grant access: {self._device_token.verification_uri_complete}')
+            input_str = input('Did you grant the access? [y/N] ')
+            if input_str != 'y':
+                return
+            self._access_token = self._user_auth.create_access_token(device_code=self._device_token.device_code)
+            print('Login successful! You are now authorized.')
+
+        if save_credentials:
+            logger.info(f'Save credentials at {credentials_location}')
+            self._user_auth.save_credentials(self._access_token, credentials_location)
 
     @property
     def host(self):
